==> spotify_openapi-0.0.0.tar.gz: doc/ReorderOrReplacePlaylistsTracksRequest.md <==
# spotify_openapi.model.ReorderOrReplacePlaylistsTracksRequest

## Load the model package
```dart
import 'package:spotify_openapi/api.dart';
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**uris** | **List&lt;String&gt;** |  | [optional] 
**rangeStart** | **int** | The position of the first item to be reordered.  | [optional] 
**insertBefore** | **int** | The position where the items should be inserted.<br/>To reorder the items to the end of the playlist, simply set _insert_before_ to the position after the last item.<br/>Examples:<br/>To reorder the first item to the last position in a playlist with 10 items, set _range_start_ to 0, and _insert_before_ to 10.<br/>To reorder the last item in a playlist with 10 items to the start of the playlist, set _range_start_ to 9, and _insert_before_ to 0.  | [optional] 
**rangeLength** | **int** | The amount of items to be reordered. Defaults to 1 if not set.<br/>The range of items to be reordered begins from the _range_start_ position, and includes the _range_length_ subsequent items.<br/>Example:<br/>To move the items at index 9-10 to the start of the playlist, _range_start_ is set to 9, and _range_length_ is set to 2.  | [optional] 
**snapshotId** | **String** | The playlist's snapshot ID against which you want to make the changes.  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> spotify_openapi-0.0.1.tar.gz: doc/ReorderOrReplacePlaylistsTracksRequest.md <==
# spotify_openapi.model.ReorderOrReplacePlaylistsTracksRequest

## Load the model package
```dart
import 'package:spotify_openapi/api.dart';
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**uris** | **BuiltList&lt;String&gt;** |  | [optional] 
**rangeStart** | **int** | The position of the first item to be reordered.  | [optional] 
**insertBefore** | **int** | The position where the items should be inserted.<br/>To reorder the items to the end of the playlist, simply set _insert_before_ to the position after the last item.<br/>Examples:<br/>To reorder the first item to the last position in a playlist with 10 items, set _range_start_ to 0, and _insert_before_ to 10.<br/>To reorder the last item in a playlist with 10 items to the start of the playlist, set _range_start_ to 9, and _insert_before_ to 0.  | [optional] 
**rangeLength** | **int** | The amount of items to be reordered. Defaults to 1 if not set.<br/>The range of items to be reordered begins from the _range_start_ position, and includes the _range_length_ subsequent items.<br/>Example:<br/>To move the items at index 9-10 to the start of the playlist, _range_start_ is set to 9, and _range_length_ is set to 2.  | [optional] 
**snapshotId** | **String** | The playlist's snapshot ID against which you want to make the changes.  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
